.. gramex documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Gramex: Gramener's Visualization Server
=======================================

.. toctree::
   :maxdepth: 2
   :caption: Captions
   :titlesonly:

   About <readme>
   design
   API <gramex>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
